# Generated by Django 5.0.4 on 2024-04-22 07:28

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("api", "0008_container_port_alter_container_container_id_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="container",
            name="port",
            field=models.PositiveIntegerField(
                default=8787,
                help_text="The port on which the container's RStudio instance is accessible.",
            ),
        ),
    ]
