# Generated by Django 5.0.4 on 2024-04-22 07:27

import r_shepard.api.models
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("api", "0007_alter_container_container_id"),
    ]

    operations = [
        migrations.AddField(
            model_name="container",
            name="port",
            field=models.PositiveIntegerField(
                default=8787,
                help_text="The port on which the container's RStudio instance is accessible.",
                max_length=5,
            ),
        ),
        migrations.AlterField(
            model_name="container",
            name="container_id",
            field=models.CharField(
                default=r_shepard.api.models.Container.generate_container_id,
                help_text="The unique identifier of the container within the project.",
                max_length=8,
            ),
        ),
        migrations.AlterField(
            model_name="project",
            name="data_path",
            field=models.CharField(
                help_text="Filesystem path where project data is stored. Containers have read access here.",
                max_length=1024,
            ),
        ),
        migrations.AlterField(
            model_name="project",
            name="workspace_path",
            field=models.CharField(
                help_text="Filesystem path where R scripts are stored. The containers have write access here.",
                max_length=1024,
            ),
        ),
        migrations.AlterUniqueTogether(
            name="container",
            unique_together={("project", "container_id")},
        ),
    ]
