# Generated by Django 5.0.4 on 2024-04-22 05:25

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("api", "0006_remove_project_cpus_remove_project_is_active_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="container",
            name="container_id",
            field=models.CharField(
                help_text="The unique identifier of the container.",
                max_length=5,
                unique=True,
            ),
        ),
    ]
