# Generated by Django 5.0.4 on 2024-05-08 13:12

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("api", "0017_alter_container_container_id_alter_container_cpus_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="project",
            name="description",
            field=models.CharField(
                default="",
                help_text="A short description of your project (max. 1025 characters)",
                max_length=1024,
            ),
        ),
    ]
