# Generated by Django 5.0.4 on 2024-05-10 09:10

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("api", "0018_project_description"),
    ]

    operations = [
        migrations.AlterField(
            model_name="project",
            name="commit_interval",
            field=models.PositiveIntegerField(
                default=15, help_text="Commit interval in minutes.", null=True
            ),
        ),
        migrations.AlterField(
            model_name="project",
            name="git_repo_url",
            field=models.CharField(
                blank=True,
                help_text="URL of the Git repository.",
                max_length=255,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "(git@|http:\\/\\/|https:\\/\\/)([\\w\\.@:]+)(\\/|:)([\\w\\.\\/\\-]+\\.git)",
                        "Enter a valid Git URL.",
                    )
                ],
                verbose_name="Git Repository URL",
            ),
        ),
        migrations.AlterField(
            model_name="project",
            name="max_containers",
            field=models.PositiveIntegerField(
                default=4,
                help_text="Maximum number of containers that can be run for the project.",
                verbose_name="Max. number of containers",
            ),
        ),
        migrations.AlterField(
            model_name="project",
            name="max_cpus",
            field=models.PositiveIntegerField(
                default=8,
                help_text="Maximum number of CPUs allocated to the project.",
                verbose_name="Max. CPUs",
            ),
        ),
        migrations.AlterField(
            model_name="project",
            name="max_ram",
            field=models.PositiveIntegerField(
                default=32,
                help_text="Maximum amount of RAM in GB allocated for the project.",
                verbose_name="Max. RAM",
            ),
        ),
        migrations.AlterField(
            model_name="project",
            name="name",
            field=models.CharField(
                help_text="The name of the project.",
                max_length=255,
                unique=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^[\\w\\s]+$",
                        "Enter a valid project name. This value may contain only letters, numbers, and whitespace.",
                    )
                ],
            ),
        ),
    ]
